@@ -7,11 +7,11 @@ var searchData=
   ['getleaf_4',['GetLeaf',['../structnanovdb_1_1GetLeaf.html',1,'nanovdb']]],
   ['getlower_5',['GetLower',['../structnanovdb_1_1GetLower.html',1,'nanovdb']]],
   ['getnodeinfo_6',['GetNodeInfo',['../structnanovdb_1_1GetNodeInfo.html',1,'nanovdb']]],
-  ['getstate_7',['getstate',['../structnanovdb_1_1build_1_1GetState.html',1,'GetState&lt; T &gt;'],['../structnanovdb_1_1GetState.html',1,'GetState&lt; BuildT &gt;']]],
+  ['getstate_7',['GetState',['../structnanovdb_1_1build_1_1GetState.html',1,'GetState&lt; T &gt;'],['../structnanovdb_1_1GetState.html',1,'GetState&lt; BuildT &gt;']]],
   ['getupper_8',['GetUpper',['../structnanovdb_1_1GetUpper.html',1,'nanovdb']]],
-  ['getvalue_9',['getvalue',['../structnanovdb_1_1build_1_1GetValue.html',1,'GetValue&lt; T &gt;'],['../structnanovdb_1_1GetValue.html',1,'GetValue&lt; BuildT &gt;']]],
+  ['getvalue_9',['GetValue',['../structnanovdb_1_1build_1_1GetValue.html',1,'GetValue&lt; T &gt;'],['../structnanovdb_1_1GetValue.html',1,'GetValue&lt; BuildT &gt;']]],
   ['globalmovepointsop_10',['GlobalMovePointsOp',['../structopenvdb_1_1v11__0_1_1points_1_1point__move__internal_1_1GlobalMovePointsOp.html',1,'openvdb::v11_0::points::point_move_internal']]],
-  ['gradient_11',['gradient',['../structopenvdb_1_1v11__0_1_1math_1_1Gradient.html',1,'Gradient&lt; MapType, DiffScheme &gt;'],['../classopenvdb_1_1v11__0_1_1tools_1_1Gradient.html',1,'Gradient&lt; InGridT, MaskGridType, InterruptT &gt;']]],
+  ['gradient_11',['Gradient',['../structopenvdb_1_1v11__0_1_1math_1_1Gradient.html',1,'Gradient&lt; MapType, DiffScheme &gt;'],['../classopenvdb_1_1v11__0_1_1tools_1_1Gradient.html',1,'Gradient&lt; InGridT, MaskGridType, InterruptT &gt;']]],
   ['gradient_3c_20scalemap_2c_20cd_5f2nd_20_3e_12',['Gradient&lt; ScaleMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Gradient_3_01ScaleMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
   ['gradient_3c_20scaletranslatemap_2c_20cd_5f2nd_20_3e_13',['Gradient&lt; ScaleTranslateMap, CD_2ND &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Gradient_3_01ScaleTranslateMap_00_01CD__2ND_01_4.html',1,'openvdb::v11_0::math']]],
   ['gradient_3c_20translationmap_2c_20diffscheme_20_3e_14',['Gradient&lt; TranslationMap, DiffScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1Gradient_3_01TranslationMap_00_01DiffScheme_01_4.html',1,'openvdb::v11_0::math']]],
@@ -21,9 +21,9 @@ var searchData=
   ['gradientnormsqrd_18',['GradientNormSqrd',['../structopenvdb_1_1v11__0_1_1math_1_1GradientNormSqrd.html',1,'openvdb::v11_0::math']]],
   ['gradientnormsqrd_3c_20uniformscalemap_2c_20gradscheme_20_3e_19',['GradientNormSqrd&lt; UniformScaleMap, GradScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1GradientNormSqrd_3_01UniformScaleMap_00_01GradScheme_01_4.html',1,'openvdb::v11_0::math']]],
   ['gradientnormsqrd_3c_20uniformscaletranslatemap_2c_20gradscheme_20_3e_20',['GradientNormSqrd&lt; UniformScaleTranslateMap, GradScheme &gt;',['../structopenvdb_1_1v11__0_1_1math_1_1GradientNormSqrd_3_01UniformScaleTranslateMap_00_01GradScheme_01_4.html',1,'openvdb::v11_0::math']]],
-  ['gradstencil_21',['gradstencil',['../classnanovdb_1_1GradStencil.html',1,'GradStencil&lt; GridT &gt;'],['../classopenvdb_1_1v11__0_1_1math_1_1GradStencil.html',1,'GradStencil&lt; GridT, IsSafe &gt;']]],
+  ['gradstencil_21',['GradStencil',['../classnanovdb_1_1GradStencil.html',1,'GradStencil&lt; GridT &gt;'],['../classopenvdb_1_1v11__0_1_1math_1_1GradStencil.html',1,'GradStencil&lt; GridT, IsSafe &gt;']]],
   ['gradstencil_3c_20gridt_2c_20false_20_3e_22',['GradStencil&lt; GridT, false &gt;',['../classopenvdb_1_1v11__0_1_1math_1_1GradStencil.html',1,'openvdb::v11_0::math']]],
-  ['grid_23',['grid',['../structnanovdb_1_1build_1_1Grid.html',1,'Grid&lt; BuildT &gt;'],['../classnanovdb_1_1Grid.html',1,'Grid&lt; TreeT &gt;'],['../classopenvdb_1_1v11__0_1_1Grid.html',1,'Grid&lt; _TreeType &gt;']]],
+  ['grid_23',['Grid',['../structnanovdb_1_1build_1_1Grid.html',1,'Grid&lt; BuildT &gt;'],['../classnanovdb_1_1Grid.html',1,'Grid&lt; TreeT &gt;'],['../classopenvdb_1_1v11__0_1_1Grid.html',1,'Grid&lt; _TreeType &gt;']]],
   ['grid_3c_20nanovdb_3a_3apoint_20_3e_24',['Grid&lt; nanovdb::Point &gt;',['../classnanovdb_1_1Grid.html',1,'nanovdb']]],
   ['grid_3c_20uint32_5ft_20_3e_25',['Grid&lt; uint32_t &gt;',['../classnanovdb_1_1Grid.html',1,'nanovdb']]],
   ['grid_3c_20valueindex_20_3e_26',['Grid&lt; ValueIndex &gt;',['../classnanovdb_1_1Grid.html',1,'nanovdb']]],
@@ -43,15 +43,16 @@ var searchData=
   ['gridsampler_40',['GridSampler',['../classopenvdb_1_1v11__0_1_1tools_1_1GridSampler.html',1,'openvdb::v11_0::tools']]],
   ['gridsampler_3c_20tree_3a_3avalueaccessor_3c_20treet_20_3e_2c_20samplertype_20_3e_41',['GridSampler&lt; tree::ValueAccessor&lt; TreeT &gt;, SamplerType &gt;',['../classopenvdb_1_1v11__0_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html',1,'openvdb::v11_0::tools']]],
   ['gridstats_42',['GridStats',['../classnanovdb_1_1GridStats.html',1,'nanovdb']]],
-  ['gridtransformer_43',['GridTransformer',['../classopenvdb_1_1v11__0_1_1tools_1_1GridTransformer.html',1,'openvdb::v11_0::tools']]],
-  ['gridtransformop_44',['GridTransformOp',['../classopenvdb__houdini_1_1GridTransformOp.html',1,'openvdb_houdini']]],
-  ['gridtree_45',['GridTree',['../structnanovdb_1_1GridTree.html',1,'nanovdb']]],
-  ['gridtree_3c_20const_20gridt_20_3e_46',['GridTree&lt; const GridT &gt;',['../structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html',1,'nanovdb']]],
-  ['gridvalidator_47',['GridValidator',['../classnanovdb_1_1GridValidator.html',1,'nanovdb']]],
-  ['groupcodec_48',['GroupCodec',['../structopenvdb_1_1v11__0_1_1points_1_1GroupCodec.html',1,'openvdb::v11_0::points']]],
-  ['groupfilter_49',['GroupFilter',['../classopenvdb_1_1v11__0_1_1points_1_1GroupFilter.html',1,'openvdb::v11_0::points']]],
-  ['grouphandle_50',['GroupHandle',['../classopenvdb_1_1v11__0_1_1points_1_1GroupHandle.html',1,'openvdb::v11_0::points']]],
-  ['groupwritehandle_51',['GroupWriteHandle',['../classopenvdb_1_1v11__0_1_1points_1_1GroupWriteHandle.html',1,'openvdb::v11_0::points']]],
-  ['gt_5fgeoprimcollectvdb_52',['GT_GEOPrimCollectVDB',['../classopenvdb__houdini_1_1GT__GEOPrimCollectVDB.html',1,'openvdb_houdini']]],
-  ['gu_5fvdbpointlist_53',['GU_VDBPointList',['../structGU__VDBPointList.html',1,'']]]
+  ['gridtorasterize_43',['GridToRasterize',['../classopenvdb_1_1v11__0_1_1points_1_1point__rasterize__internal_1_1GridToRasterize.html',1,'openvdb::v11_0::points::point_rasterize_internal']]],
+  ['gridtransformer_44',['GridTransformer',['../classopenvdb_1_1v11__0_1_1tools_1_1GridTransformer.html',1,'openvdb::v11_0::tools']]],
+  ['gridtransformop_45',['GridTransformOp',['../classopenvdb__houdini_1_1GridTransformOp.html',1,'openvdb_houdini']]],
+  ['gridtree_46',['GridTree',['../structnanovdb_1_1GridTree.html',1,'nanovdb']]],
+  ['gridtree_3c_20const_20gridt_20_3e_47',['GridTree&lt; const GridT &gt;',['../structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html',1,'nanovdb']]],
+  ['gridvalidator_48',['GridValidator',['../classnanovdb_1_1GridValidator.html',1,'nanovdb']]],
+  ['groupcodec_49',['GroupCodec',['../structopenvdb_1_1v11__0_1_1points_1_1GroupCodec.html',1,'openvdb::v11_0::points']]],
+  ['groupfilter_50',['GroupFilter',['../classopenvdb_1_1v11__0_1_1points_1_1GroupFilter.html',1,'openvdb::v11_0::points']]],
+  ['grouphandle_51',['GroupHandle',['../classopenvdb_1_1v11__0_1_1points_1_1GroupHandle.html',1,'openvdb::v11_0::points']]],
+  ['groupwritehandle_52',['GroupWriteHandle',['../classopenvdb_1_1v11__0_1_1points_1_1GroupWriteHandle.html',1,'openvdb::v11_0::points']]],
+  ['gt_5fgeoprimcollectvdb_53',['GT_GEOPrimCollectVDB',['../classopenvdb__houdini_1_1GT__GEOPrimCollectVDB.html',1,'openvdb_houdini']]],
+  ['gu_5fvdbpointlist_54',['GU_VDBPointList',['../structGU__VDBPointList.html',1,'']]]
 ];
